@@ -15,18 +15,13 @@ def logit(message):
     sys.stdout.flush()
 
 def blink():
-    logit("high")
-    GPIO.output(LED_PIN, GPIO.HIGH)
-    time.sleep(2)
-    logit("low")
-    GPIO.output(LED_PIN, GPIO.LOW)
+    while True:
+        GPIO.output(LED_PIN, GPIO.HIGH)
+        db.set_key("led_state", "high")
+        print(db.get_value_by_key("led_state"))
+        time.sleep(2)
 
-
-if __name__ == '__main__':
-    try:
-        while True:
-            time.sleep(2)
-            blink()
-    except:
-        logit("Bye!")
-        GPIO.cleanup()
\ No newline at end of file
+        GPIO.output(LED_PIN, GPIO.LOW)
+        db.set_key("led_state", "high")
+        print(db.get_value_by_key("led_state"))
+        time.sleep(2)
\ No newline at end of file
